@@ -7,11 +7,7 @@ use lib '../..';
 
 use base qw(App::Followme::CreateIndex);
 
-use IO::File;
-use File::Spec::Functions qw(abs2rel rel2abs splitdir catfile);
-use App::Followme::FIO;
-
-our $VERSION = "2.01";
+our $VERSION = "2.02";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
