@@ -9,10 +9,10 @@ use lib '../..';
 use base qw(App::Followme::FileData);
 
 use Image::Size;
-use File::Spec::Functions qw(abs2rel rel2abs splitdir catfile);
+use File::Spec::Functions qw(catfile);
 use App::Followme::FIO;
 
-our $VERSION = "2.01";
+our $VERSION = "2.02";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
